package TableDef;

our $VERSION = '1.0.7'; # VERSION
our $DATE = '2016-03-08'; # DATE

1;
# ABSTRACT: Table data definition

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDef - Table data definition

=head1 VERSION

This document describes version 1.0.7 of TableDef (from Perl distribution TableDef), released on 2016-03-08.

=head1 SAH SCHEMAS

=over

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDef>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDef>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDef>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
